# County rural/urban classification
# Core-Based statistical areas (CBSA)
# ftp://ftp.cdc.gov/pub/Health_Statistics/NCHS/Datasets/OAE/urbanrural/NCHSURCodes2013.txt
# http://www.cdc.gov/nchs/data_access/urban_rural.htm#documentation

widths = diff(c(1, 7, 10, 47, 98, 107, 116, 118, 120, 121))
data = read.fwf("NCHSURCodes2013.txt", widths, as.is=T, strip.white=T)
colnames(data) = c("FIPS", "ST", "COUNTYNAME", "CBSA", "CBSPOP2013", "POP2013", "URBAN2013", "URBAN2006", "URBAN1990")
data$FIPS = sprintf("%05d", data$FIPS)
rownames(data) = data$FIPS
suppressWarnings(data$POP2013 <- as.numeric(data$POP2013))
suppressWarnings(data$CBSPOP2013 <- as.numeric(data$CBSPOP2013))
suppressWarnings(data$URBAN1990 <- as.integer(data$URBAN1990))


# Census Regions

data$REGION = NA
data[data$ST %in% c("WA","OR","CA","NV","ID", "MT","WY","UT","CO","AZ","NM"), "REGION"] = "West"
data[data$ST %in% c("ND", "SD", "NE", "KS","MN","IA", "MO", "WI", "IL", "IN","MI","OH"), "REGION"] = "Midwest"
data[data$ST %in% c("OK", "TX", "AR", "LA", "MS", "KY", "TN", "AL",
	"FL", "GA", "SC", "NC", "WV", "VA", "MD", "DC", "DE"), "REGION"] = "South"
data[data$ST %in% c("PA", "NJ", "NY", "CT", "MA", "RI", "VT", "NH", "ME"), "REGION"] = "Northeast"



# 2012 Election Results
# http://www.theguardian.com/news/datablog/2012/nov/07/us-2012-election-county-results-download
# https://www.google.com/fusiontables/DataSource?docid=1qcQLqrAIAe3RcEfdWSm_QcXMLmteVg4uSpSs1rM#rows:id=1
# http://censtats.census.gov/usa/usa.shtml

#election = read.csv("2012-elections.csv", as.is=T)
#election = election[election$FIPS.Code != 0,]
#election$FIPS.Code = sprintf("%05d", election$FIPS.Code)
#election$DEM2012 = ifelse(election[,13] == "Dem", election[,20], 
#	ifelse(election[,25] == "Dem", election[,32],
#	ifelse(election[,37] == "Dem", election[,45],
#	ifelse(election[,49] == "Dem", election[,56], NA))))
#election$GOP2012 = ifelse(election[,13] == "GOP", election[,20], 
#	ifelse(election[,25] == "GOP", election[,32],
#	ifelse(election[,37] == "GOP", election[,45],
#	ifelse(election[,49] == "GOP", election[,56], NA))))

#election$DEM2012 = as.numeric(election$DEM2012)
#election$GOP2012 = as.numeric(election$GOP2012)

#columns = c("FIPS.Code", "TOTAL.VOTES.CAST", "DEM2012", "GOP2012")
#election = election[,columns]
#colnames(election) = c("FIPS", "VOTES2012", "DEM2012", "GOP2012")

# Some states have multiple counties within a single FIPS code
#election = aggregate(election[,c("VOTES2012", "DEM2012", "GOP2012")], by = list(election$FIPS), FUN=sum)
#colnames(election) = c("FIPS", "VOTES2012", "DEM2012", "GOP2012")

#election$WIN2012 = ifelse(election$DEM2012 > election$GOP2012, "Obama", "Romney")
#rownames(election) = election$FIPS

#data$VOTES2012 = election[data$FIPS,"VOTES2012"]
#data$DEM2012 = election[data$FIPS,"DEM2012"]
#data$GOP2012 = election[data$FIPS,"GOP2012"]
#data$WIN2012 = election[data$FIPS,"WIN2012"]

#data$PCDEM2012 = ifelse(is.na(data$VOTES2012) | is.na(data$DEM2012), NA, 
#	ifelse(data$VOTES2012 <= 0, NA, data$DEM2012 / data$VOTES2012))
#data$PCGOP2012 = ifelse(is.na(data$VOTES2012) | is.na(data$GOP2012), NA, 
#	ifelse(data$VOTES2012 <= 0, NA, data$GOP2012 / data$VOTES2012))


# 2012/2016 Election Results: http://www.politico.com/2016-election/results/map/president

election = read.csv("2016-election.csv", as.is=T)
election$FIPS = sprintf("%05d", election$FIPS)

columns = c("DEM2012", "PCDEM2012", "GOP2012", "PCGOP2012", "DEM2016", "PCDEM2016", "GOP2016", "PCGOP2016")

suppressWarnings(election[,columns] <- sapply(election[,columns], function(x) gsub(",", "", x)))
suppressWarnings(election[,columns] <- sapply(election[,columns], as.numeric))

data = merge(x=data, y=election[, c("FIPS", "WIN2012", "WIN2016", columns)], by = "FIPS", all.x=T)



# Voter turnout change between 2012 and 2016

data$CHANGEDEM = 100 * ((data$DEM2016 / data$DEM2012) - 1)
data$CHANGEGOP = 100 * ((data$GOP2016 / data$GOP2012) - 1)


# http://www.cdc.gov/diabetes/atlas/countydata/County_ListofIndicators.html
obesity = read.csv("OB_PREV_ALL_STATES.csv", skip=1, as.is=T)
obesity = obesity[,c(2, 61)]
colnames(obesity) = c("FIPS", "PCOBESITY")
obesity$FIPS = sprintf("%05d", obesity$FIPS)
obesity$PCOBESITY <- as.numeric(obesity$PCOBESITY)

data = merge(x=data, y=obesity, by="FIPS", all.x=T, suffixes=c("",""))
data$OBESITY = ifelse(data$PCOBESITY < 29, "Low", "High")


# 2015 ACS Five-Year Estimates, Median Household Income

income = read.csv("ACS_15_5YR_B19013_with_ann.csv", as.is=T)
income = income[-1,]
rownames(income) = income$GEO.id2
data$MEDHHINC = income[data$FIPS, "HD01_VD01"]
data$MEDHHINC = as.numeric(data$MEDHHINC)

# 2015 ACS Five-Year Estimates, MEDIAN MONTHLY HOUSING COSTS (DOLLARS)

housing = read.csv("ACS_15_5YR_B25105_with_ann.csv", as.is=T)
housing = housing[-1,]
rownames(housing) = housing$GEO.id2
data$MEDHOUSE = housing[data$FIPS, "HD01_VD01"]
data$MEDHOUSE = as.numeric(data$MEDHOUSE)


# 2015 ACS Five-Year Estimates, MEDIAN AGE BY SEX

age = read.csv("ACS_15_5YR_B01002_with_ann.csv", as.is=T)
age = age[-1,]
age = age[,c("GEO.id2", "HD01_VD02")]
colnames(age) = c("FIPS","MEDAGE")
suppressWarnings(age$MEDAGE <- as.numeric(age$MEDAGE))
data = merge(x=data, y=age, by="FIPS", all.x=T)



# County polygons for mapping
# https://www.census.gov/geo/maps-data/data/cbf/cbf_counties.html

library(rgdal)
polygons = readOGR(dsn=".", layer="cb_2015_us_county_500k", stringsAsFactors=F)
polygons@data$ALAND = as.numeric(polygons@data$ALAND)
polygons@data$AWATER = as.numeric(polygons@data$AWATER)

polygons@data$AREASQMI = round((polygons@data$ALAND + polygons@data$AWATER) / 2590000)

names(polygons)[which(names(polygons) == "GEOID")] = "FIPS"

polygons = merge(x=polygons, y = data, by = "FIPS", all.x=T)

polygons@data[,c("STATEFP", "COUNTYFP", "COUNTYNS", "AFFGEOID", "LSAD", "ALAND", "AWATER", "COUNTYNAME")] = NULL

polygons@data$POPSQM2013 = polygons@data$POP2013 / polygons@data$AREASQMI


# Fix some missing codes for states not in tabular data

polygons$ST[polygons$STATEFP == "02"] = "AK"
polygons$ST[polygons$STATEFP == "60"] = "AS"
polygons$ST[polygons$STATEFP == "69"] = "MP"
polygons$ST[polygons$STATEFP == "72"] = "PR"
polygons$ST[polygons$STATEFP == "78"] = "VI"
polygons$ST[polygons$STATEFP == "46"] = "SD"
polygons$ST[polygons$STATEFP == "66"] = "GU"

# Remove territories
polygons = polygons[!(polygons$ST %in% c("AS", "GU","MP","PR","VI")),]

writeOGR(polygons, dsn='.', layer="county-data", driver="ESRI Shapefile", overwrite_layer=T)

data = polygons@data
write.csv(data, "county-data.csv", row.names=F, na="")



# Analysis
#dev.new()
#boxplot(PCOBESITY ~ URBAN2013, data=data, main="Obesity by Urban/Rural")

#dev.new()
#boxplot(PCOBESITY ~ WIN2012, data=data, main="Obesity by 2012 Election Winner")

#dev.new()
#boxplot(PCOBESITY ~ REGION, data=data, main="Obesity by Region")

print(chisq.test(data$WIN2012, data$OBESITY))

print(kruskal.test(data$PCDEM2012, as.factor(data$OBESITY)))

print(kruskal.test(data$PCOBESITY, as.factor(data$REGION)))

print(kruskal.test(data$PCOBESITY, as.factor(data$WIN2012)))

# dev.new()
plot(data$MEDHHINC, data$PCOBESITY, col="#00000040")
model=lm(PCOBESITY ~ MEDHHINC, data=data)
abline(model, col="navy", lwd=3)
print(summary(model))

# http://www.biostathandbook.com/transformation.html
# "Parametric tests aren't extremely sensitive to deviations from their assumptions."

plot(log(data$MEDHHINC), data$PCOBESITY, col="#00000040")
model=lm(PCOBESITY ~ log(MEDHHINC), data=data)
abline(model, col="navy", lwd=3)
print(summary(model))

#polygons = polygons[!(polygons$ST %in% c("AK", "HI")),]
#spplot(polygons, xlim=c(-130, -62), ylim=c(23,51), zcol="PCDEM2012")

